@@ -54,7 +54,7 @@ class GA:
         self.total_bits = self.n_param*self.r
         self.do_crossover = do_crossover
         self.rng = np.random.default_rng(rng_seed)
-        self.G = self.rng.randint(0,2,size=(self.pop_size,self.total_bits)) #Genetic Algorithm state. Lines are individuals.
+        self.G = self.rng.integers(0,2,size=(self.pop_size,self.total_bits)) #Genetic Algorithm state. Lines are individuals.
         
     def mutation(self):
         i = self.elitism
@@ -118,7 +118,7 @@ class GA:
         is selected, the fittest individual of the last generation lives on and replaces one of the
         generated individuals.
         """
-        cut = self.rng.randint(0,self.total_bits) if self.do_crossover else 0
+        cut = self.rng.integers(0,self.total_bits) if self.do_crossover else 0
         cross_size = self.pop_size//2 + 1
         
         pairs = self.rng.choice(range(self.pop_size),p=self.p,size=(cross_size,2))
